Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1131)

Unified Diff: chrome/browser/ui/views/location_bar/location_bar_decoration_view.h

Issue 11418043: Remove TabContents from OmniboxEditController and friends. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: cros Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/location_bar/location_bar_decoration_view.h
diff --git a/chrome/browser/ui/views/location_bar/location_bar_decoration_view.h b/chrome/browser/ui/views/location_bar/location_bar_decoration_view.h
index d34cb1dd9983f047f82c236b63192176a8636ab7..97629413ab273e85192dff2805a26207a99cf70b 100644
--- a/chrome/browser/ui/views/location_bar/location_bar_decoration_view.h
+++ b/chrome/browser/ui/views/location_bar/location_bar_decoration_view.h
@@ -17,7 +17,6 @@
#include "ui/views/view.h"
class LocationBarView;
-class TabContents;
namespace content {
class WebContents;
@@ -49,8 +48,8 @@ class LocationBarDecorationView : public views::View,
SkColor font_color);
virtual ~LocationBarDecorationView();
- // Update the decoration from the shown TabContents.
- virtual void Update(TabContents* tab_contents) = 0;
+ // Update the decoration from the shown WebContents.
+ virtual void Update(content::WebContents* web_contents) = 0;
void SetImage(const gfx::ImageSkia* image_skia);
void SetTooltipText(const string16& tooltip);

Powered by Google App Engine
This is Rietveld 408576698